"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fuzzyMatch = void 0;
function findSequentialIndexes(search, target) {
    const matchedIndexes = [];
    for (let i = 0; i < search.length; i++) {
        const char = search[i];
        const previousMatchIndex = matchedIndexes.length === 0 ? -1 : matchedIndexes[matchedIndexes.length - 1];
        const matchedIndex = target.indexOf(char, previousMatchIndex + 1);
        matchedIndexes.push(matchedIndex);
    }
    return matchedIndexes;
}
function fuzzyMatch(search, target) {
    const matchedIndexes = findSequentialIndexes(search.toLowerCase(), target.toLowerCase())
        .filter(index => index !== -1);
    const matchScore = matchedIndexes.length / search.length;
    if (matchScore < 1) {
        return 0;
    }
    const maxPrefixIndex = Math.min(3, target.length - 1);
    let prefixBonus = 0;
    let continuityBonus = 0;
    for (let i = 0; i < matchedIndexes.length; i++) {
        const charDistance = i === 0 ? 0 : matchedIndexes[i] - matchedIndexes[i - 1];
        prefixBonus += Math.max(0, maxPrefixIndex - matchedIndexes[i]);
        continuityBonus += charDistance === 1 ? 1 : 0;
    }
    return matchScore + prefixBonus + continuityBonus;
}
exports.fuzzyMatch = fuzzyMatch;
//# sourceMappingURL=fuzzy.js.map